==> lifefit-1.0.2.tar.gz: lifefit-1.0.2/README.md <==
# <img src="https://raw.githubusercontent.com/fdsteffen/Lifefit/master/docs/source/_static/lifefit_logo.png" width="50">LifeFit
[![Build Status](https://github.com/fdsteffen/LifeFit/workflows/LifeFit%20build/badge.svg)](https://github.com/fdsteffen/LifeFit/actions)
[![Documentation Status](https://readthedocs.org/projects/lifefit/badge/?version=latest)](https://lifefit.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/lifefit)](https://pypi.org/project/lifefit/)
[![Anaconda-Server Badge](https://anaconda.org/fdsteffen/lifefit/badges/installer/conda.svg)](https://conda.anaconda.org/fdsteffen)

## What is LifeFit
LifeFit is a Python package to analyze **time-correlated single-photon counting (TCSPC)** data sets, namely **fluorescence lifetime** and **time-resolve anisotropy** decays.

## Installation
There are different options how to install LifeFit. 

### Conda
Install LifeFit into your conda environment 
```
conda install -c fdsteffen lifefit
```

### PyPi
Alternatively, you can install the latest release of LifeFit with pip
```
pip install lifefit
```

### Install from source
Finally, you can also get the latest development version directly from Github
```
pip install git+https://github.com/fdsteffen/Lifefit.git
```

## Dependencies
Lifefit depends on the following Python packages:
- numpy
- scipy
- uncertainties 

## Documentation
LifeFit is documented [here](https://lifefit.readthedocs.io/en/latest/). To get started you might consider having a look at this [tutorial](https://lifefit.readthedocs.io/en/latest/tutorial/lifefit_tutorial.html).

## Bug reports
Please report any *bugs* via the [issue tracker](https://github.com/fdsteffen/Lifefit/issues)

## References
F.D. Steffen, R.K.O. Sigel, R. Börner, *Phys. Chem. Chem. Phys.* **2016**, *18*, 29045-29055. [![](https://img.shields.io/badge/DOI-10.1039/C6CP04277E-blue.svg)](https://doi.org/10.1039/C6CP04277E)

==> lifefit-1.0.3.tar.gz: lifefit-1.0.3/README.md <==
# <img src="https://raw.githubusercontent.com/fdsteffen/Lifefit/master/docs/source/_static/lifefit_logo.png" width="50">LifeFit
[![Build Status](https://github.com/fdsteffen/LifeFit/workflows/LifeFit%20build/badge.svg)](https://github.com/fdsteffen/LifeFit/actions)
[![Documentation Status](https://readthedocs.org/projects/lifefit/badge/?version=latest)](https://lifefit.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/lifefit)](https://pypi.org/project/lifefit/)
[![Anaconda-Server Badge](https://anaconda.org/fdsteffen/lifefit/badges/installer/conda.svg)](https://conda.anaconda.org/fdsteffen)

## What is LifeFit
LifeFit is a Python package to analyze **time-correlated single-photon counting (TCSPC)** data sets, namely **fluorescence lifetime** and **time-resolve anisotropy** decays.

## Webserver
You can run LifeFit directly in your browser: https://tcspc-lifefit.herokuapp.com/

## Installation
There are different options how to install LifeFit. 

### Conda
Install the package into your conda environment 
```
conda install -c fdsteffen lifefit
```

### PyPI
Alternatively, you can install the latest release with pip
```
pip install lifefit
```

### Install from source
Finally, you can also get the latest development version directly from Github
```
pip install git+https://github.com/fdsteffen/Lifefit.git
```

## Dependencies
Lifefit depends on the following Python packages:
- numpy
- scipy
- uncertainties 

## Documentation
LifeFit is documented [here](https://lifefit.readthedocs.io/en/latest/). To get started you might consider having a look at this [tutorial](https://lifefit.readthedocs.io/en/latest/tutorial/lifefit_tutorial.html).

## Bug reports
Please report any *bugs* via the [issue tracker](https://github.com/fdsteffen/Lifefit/issues)

## References
F.D. Steffen, R.K.O. Sigel, R. Börner, *Phys. Chem. Chem. Phys.* **2016**, *18*, 29045-29055. [![](https://img.shields.io/badge/DOI-10.1039/C6CP04277E-blue.svg)](https://doi.org/10.1039/C6CP04277E)
